@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"C:/msys64/clangarm64/bin/python.exe",
 
         # Package versions
-        contourpy_version="1.2.0",
-        meson_version="1.2.3",
+        contourpy_version="1.2.1",
+        meson_version="1.4.1",
         mesonpy_version="0.15.0",
         pybind11_version="2.11.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-841gg81j/lib/contourpy/util",
+        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-l_694nfb/lib/contourpy/util",
         source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-841gg81j/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-l_694nfb/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="clang",
-        compiler_version="17.0.4",
+        compiler_version="18.1.6",
         linker_id="ld.lld",
         compile_command="clang++",
 
